@@ -1,9 +1,11 @@
 package Acme::CPANModules::BloomFilters;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-28'; # DATE
+our $DATE = '2021-10-19'; # DATE
 our $DIST = 'Acme-CPANModules-BloomFilters'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $LIST = {
     summary => "Bloom filter modules on CPAN",
@@ -18,7 +20,12 @@ can configure the rate of false positives. The larger the filter, the smaller
 the rate. Some examples for application of bloom filter include: 1) checking
 whether a password is in a dictionary of millions of common/compromised
 passwords; 2) checking an email address against leak database; 3) virus pattern
-checking; 4) IP/domain blacklisting/whitelisting.
+checking; 4) IP/domain blacklisting/whitelisting. Due to its properties, it is
+sometimes combined with other data structures. For example, a small bloom filter
+can be distributed with a software to check against a database. When the answer
+from bloom filter is "possibly in set", the software can further consult on
+online database to make sure if it is indeed in set. Thus, bloom filter can be
+used to reduce the number of direct queries to database.
 
 In Perl, my default go-to choice is <pm:Algorithm::BloomFilter>, unless there's
 a specific feature I need from other implementations.
@@ -120,7 +127,7 @@ Acme::CPANModules::BloomFilters - Bloom filter modules on CPAN
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::BloomFilters (from Perl distribution Acme-CPANModules-BloomFilters), released on 2021-05-28.
+This document describes version 0.003 of Acme::CPANModules::BloomFilters (from Perl distribution Acme-CPANModules-BloomFilters), released on 2021-10-19.
 
 =head1 DESCRIPTION
 
@@ -133,7 +140,12 @@ can configure the rate of false positives. The larger the filter, the smaller
 the rate. Some examples for application of bloom filter include: 1) checking
 whether a password is in a dictionary of millions of common/compromised
 passwords; 2) checking an email address against leak database; 3) virus pattern
-checking; 4) IP/domain blacklisting/whitelisting.
+checking; 4) IP/domain blacklisting/whitelisting. Due to its properties, it is
+sometimes combined with other data structures. For example, a small bloom filter
+can be distributed with a software to check against a database. When the answer
+from bloom filter is "possibly in set", the software can further consult on
+online database to make sure if it is indeed in set. Thus, bloom filter can be
+used to reduce the number of direct queries to database.
 
 In Perl, my default go-to choice is L<Algorithm::BloomFilter>, unless there's
 a specific feature I need from other implementations.
@@ -222,6 +234,8 @@ or directly:
 This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
 result for C<lcpan related-mods> command when it comes to finding related
 modules for the modules listed in this Acme::CPANModules module.
+See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
+are found.
 
 =head1 HOMEPAGE
 
@@ -231,14 +245,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANM
 
 Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-BloomFilters>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-BloomFilters>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
@@ -249,11 +255,36 @@ L<cpanmodules> - CLI tool to let you browse/view the lists
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-BloomFilters>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
